from dataclasses import dataclass
from enum import Enum
from typing import Union, List


class PolicyProvider(Enum):
    AZURE_POLICY = 1
    AWS_CONFIG_POLICY = 2
    KUBE_BENCH = 3
    OTHER = 4


class SourceProvider(Enum):
    AWS = 1
    AZURE = 2
    KUBERNETES = 3
    GCP = 4
    NIST = 5
    CSA = 6
    CIS = 7
    OTHER = 8


@dataclass
class Policy:
    """Class to represent a Policy and reference metadata"""
    name: str
    description: str
    provider: Union[PolicyProvider, SourceProvider]
    url: str

    def __json__(self):
        return {
            'name': self.name,
            'description': self.description,
            'provider': self.provider.name,
            'url': self.url
        }


@dataclass()
class Validation:
    """Class to represent Validation metadata."""
    name: str
    description: str
    implements: List[Policy]
    references: List[Policy]
    coverage: str

    def __json__(self):
        implements_json_list = []
        references_json_list = []

        if self.implements:
            for implement in self.implements:
                if implement:
                    implements_json_list.append(implement.__json__())

        if self.references:
            for reference in self.references:
                if reference:
                    references_json_list.append(reference.__json__())

        return {
            'name': self.name,
            'description': self.description,
            'implements': implements_json_list,
            'references': references_json_list,
            'coverage': self.coverage
        }



import logging
from sys import stdout
import structlog
from structlog.stdlib import LoggerFactory


def edit_logging_event(_, __, event_dict):
    try:

        new_event_dict = event_dict
        error = event_dict.get("event")

        new_event_dict['Status'] = error.exception_type
        # new_event_dict['ErrorCode'] = error.error_code
        new_event_dict['Message'] = error.error_message
        new_event_dict['Error'] = event_dict.get("Error")
        new_event_dict['ErrorType'] = event_dict.get("ErrorType")
        new_event_dict['RequestId'] = error.request_id
        new_event_dict['Caller'] = error.validation_type
        new_event_dict.pop("event")

        return new_event_dict

    except Exception as e:
        pass

    try:

        new_event_dict = event_dict

        new_event_dict['Status'] = event_dict.get("event")
        new_event_dict['Message'] = event_dict.get("Message")
        new_event_dict['Error'] = event_dict.get("Error")
        new_event_dict['ErrorType'] = event_dict.get("ErrorType")
        new_event_dict['RequestId'] = event_dict.get("RequestId")
        new_event_dict['Caller'] = event_dict.get("Caller")
        new_event_dict.pop("event")

        return new_event_dict

    except Exception as e:
        pass

    return event_dict


def _logger():
    logging.basicConfig(
        format="%(message)s",
        stream=stdout,
        level=logging.INFO
    )

    structlog.configure(
        logger_factory=LoggerFactory(),
        processors=[
            edit_logging_event,
            structlog.processors.TimeStamper(fmt="iso", utc=True, key='Timestamp'),
            structlog.processors.add_log_level,
            structlog.processors.JSONRenderer()
        ]
    )

    log = structlog.get_logger()

    return log



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_route53resolver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ws/aws_route53resolver.proto\x12\x1foak9.tython.aws.route53resolver\x1a\x13shared/shared.proto\"z\n ResolverEndpointIpAddressRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\"\xd9\x02\n\x10ResolverEndpoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x0cip_addresses\x18\x02 \x03(\x0b\x32\x41.oak9.tython.aws.route53resolver.ResolverEndpointIpAddressRequest\x12\x11\n\tdirection\x18\x03 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x04 \x03(\t\x12I\n\x04tags\x18\x05 \x03(\x0b\x32;.oak9.tython.aws.route53resolver.ResolverEndpoint.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe1\x03\n\x0fRoute53Resolver\x12L\n\x11resolver_endpoint\x18\x01 \x03(\x0b\x32\x31.oak9.tython.aws.route53resolver.ResolverEndpoint\x12\x62\n\x1dresolver_query_logging_config\x18\x02 \x03(\x0b\x32;.oak9.tython.aws.route53resolver.ResolverQueryLoggingConfig\x12y\n)resolver_query_logging_config_association\x18\x03 \x03(\x0b\x32\x46.oak9.tython.aws.route53resolver.ResolverQueryLoggingConfigAssociation\x12\x44\n\rresolver_rule\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.route53resolver.ResolverRule\x12[\n\x19resolver_rule_association\x18\x05 \x03(\x0b\x32\x38.oak9.tython.aws.route53resolver.ResolverRuleAssociation\"|\n\x1aResolverQueryLoggingConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0f\x64\x65stination_arn\x18\x03 \x01(\t\"\x9b\x01\n%ResolverQueryLoggingConfigAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12$\n\x1cresolver_query_log_config_id\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\"n\n\x19ResolverRuleTargetAddress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\t\"\xdf\x02\n\x0cResolverRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14resolver_endpoint_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64omain_name\x18\x03 \x01(\t\x12\x11\n\trule_type\x18\x04 \x01(\t\x12N\n\ntarget_ips\x18\x05 \x03(\x0b\x32:.oak9.tython.aws.route53resolver.ResolverRuleTargetAddress\x12\x45\n\x04tags\x18\x06 \x03(\x0b\x32\x37.oak9.tython.aws.route53resolver.ResolverRule.TagsEntry\x12\x0c\n\x04name\x18\x07 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8a\x01\n\x17ResolverRuleAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06vpc_id\x18\x02 \x01(\t\x12\x18\n\x10resolver_rule_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_route53resolver_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOLVERENDPOINT_TAGSENTRY._options = None
  _RESOLVERENDPOINT_TAGSENTRY._serialized_options = b'8\001'
  _RESOLVERRULE_TAGSENTRY._options = None
  _RESOLVERRULE_TAGSENTRY._serialized_options = b'8\001'
  _RESOLVERENDPOINTIPADDRESSREQUEST._serialized_start=87
  _RESOLVERENDPOINTIPADDRESSREQUEST._serialized_end=209
  _RESOLVERENDPOINT._serialized_start=212
  _RESOLVERENDPOINT._serialized_end=557
  _RESOLVERENDPOINT_TAGSENTRY._serialized_start=514
  _RESOLVERENDPOINT_TAGSENTRY._serialized_end=557
  _ROUTE53RESOLVER._serialized_start=560
  _ROUTE53RESOLVER._serialized_end=1041
  _RESOLVERQUERYLOGGINGCONFIG._serialized_start=1043
  _RESOLVERQUERYLOGGINGCONFIG._serialized_end=1167
  _RESOLVERQUERYLOGGINGCONFIGASSOCIATION._serialized_start=1170
  _RESOLVERQUERYLOGGINGCONFIGASSOCIATION._serialized_end=1325
  _RESOLVERRULETARGETADDRESS._serialized_start=1327
  _RESOLVERRULETARGETADDRESS._serialized_end=1437
  _RESOLVERRULE._serialized_start=1440
  _RESOLVERRULE._serialized_end=1791
  _RESOLVERRULE_TAGSENTRY._serialized_start=514
  _RESOLVERRULE_TAGSENTRY._serialized_end=557
  _RESOLVERRULEASSOCIATION._serialized_start=1794
  _RESOLVERRULEASSOCIATION._serialized_end=1932
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CloudbuildTriggerXApprovalConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPROVAL_REQUIRED_FIELD_NUMBER: builtins.int
    approval_required: builtins.bool
    def __init__(
        self,
        *,
        approval_required: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["approval_required", b"approval_required"]) -> None: ...

global___CloudbuildTriggerXApprovalConfig = CloudbuildTriggerXApprovalConfig

@typing_extensions.final
class CloudbuildTriggerXBuildXArtifactsXObjects(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TimingEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    LOCATION_FIELD_NUMBER: builtins.int
    PATHS_FIELD_NUMBER: builtins.int
    TIMING_FIELD_NUMBER: builtins.int
    location: builtins.str
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def timing(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        location: builtins.str = ...,
        paths: collections.abc.Iterable[builtins.str] | None = ...,
        timing: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "paths", b"paths", "timing", b"timing"]) -> None: ...

global___CloudbuildTriggerXBuildXArtifactsXObjects = CloudbuildTriggerXBuildXArtifactsXObjects

@typing_extensions.final
class CloudbuildTriggerXBuildXArtifacts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGES_FIELD_NUMBER: builtins.int
    OBJECTS_FIELD_NUMBER: builtins.int
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def objects(self) -> global___CloudbuildTriggerXBuildXArtifactsXObjects: ...
    def __init__(
        self,
        *,
        images: collections.abc.Iterable[builtins.str] | None = ...,
        objects: global___CloudbuildTriggerXBuildXArtifactsXObjects | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["objects", b"objects"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["images", b"images", "objects", b"objects"]) -> None: ...

global___CloudbuildTriggerXBuildXArtifacts = CloudbuildTriggerXBuildXArtifacts

@typing_extensions.final
class CloudbuildTriggerXBuildXAvailableSecretsXSecretManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENV_FIELD_NUMBER: builtins.int
    VERSION_NAME_FIELD_NUMBER: builtins.int
    env: builtins.str
    version_name: builtins.str
    def __init__(
        self,
        *,
        env: builtins.str = ...,
        version_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["env", b"env", "version_name", b"version_name"]) -> None: ...

global___CloudbuildTriggerXBuildXAvailableSecretsXSecretManager = CloudbuildTriggerXBuildXAvailableSecretsXSecretManager

@typing_extensions.final
class CloudbuildTriggerXBuildXAvailableSecrets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_MANAGER_FIELD_NUMBER: builtins.int
    @property
    def secret_manager(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudbuildTriggerXBuildXAvailableSecretsXSecretManager]: ...
    def __init__(
        self,
        *,
        secret_manager: collections.abc.Iterable[global___CloudbuildTriggerXBuildXAvailableSecretsXSecretManager] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret_manager", b"secret_manager"]) -> None: ...

global___CloudbuildTriggerXBuildXAvailableSecrets = CloudbuildTriggerXBuildXAvailableSecrets

@typing_extensions.final
class CloudbuildTriggerXBuildXOptionsXVolumes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "path", b"path"]) -> None: ...

global___CloudbuildTriggerXBuildXOptionsXVolumes = CloudbuildTriggerXBuildXOptionsXVolumes

@typing_extensions.final
class CloudbuildTriggerXBuildXOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    DYNAMIC_SUBSTITUTIONS_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    LOG_STREAMING_OPTION_FIELD_NUMBER: builtins.int
    LOGGING_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    REQUESTED_VERIFY_OPTION_FIELD_NUMBER: builtins.int
    SECRET_ENV_FIELD_NUMBER: builtins.int
    SOURCE_PROVENANCE_HASH_FIELD_NUMBER: builtins.int
    SUBSTITUTION_OPTION_FIELD_NUMBER: builtins.int
    WORKER_POOL_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    disk_size_gb: builtins.float
    dynamic_substitutions: builtins.bool
    @property
    def env(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    log_streaming_option: builtins.str
    logging: builtins.str
    machine_type: builtins.str
    requested_verify_option: builtins.str
    @property
    def secret_env(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def source_provenance_hash(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    substitution_option: builtins.str
    worker_pool: builtins.str
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudbuildTriggerXBuildXOptionsXVolumes]: ...
    def __init__(
        self,
        *,
        disk_size_gb: builtins.float = ...,
        dynamic_substitutions: builtins.bool = ...,
        env: collections.abc.Iterable[builtins.str] | None = ...,
        log_streaming_option: builtins.str = ...,
        logging: builtins.str = ...,
        machine_type: builtins.str = ...,
        requested_verify_option: builtins.str = ...,
        secret_env: collections.abc.Iterable[builtins.str] | None = ...,
        source_provenance_hash: collections.abc.Iterable[builtins.str] | None = ...,
        substitution_option: builtins.str = ...,
        worker_pool: builtins.str = ...,
        volumes: collections.abc.Iterable[global___CloudbuildTriggerXBuildXOptionsXVolumes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_size_gb", b"disk_size_gb", "dynamic_substitutions", b"dynamic_substitutions", "env", b"env", "log_streaming_option", b"log_streaming_option", "logging", b"logging", "machine_type", b"machine_type", "requested_verify_option", b"requested_verify_option", "secret_env", b"secret_env", "source_provenance_hash", b"source_provenance_hash", "substitution_option", b"substitution_option", "volumes", b"volumes", "worker_pool", b"worker_pool"]) -> None: ...

global___CloudbuildTriggerXBuildXOptions = CloudbuildTriggerXBuildXOptions

@typing_extensions.final
class CloudbuildTriggerXBuildXSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SecretEnvEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    SECRET_ENV_FIELD_NUMBER: builtins.int
    kms_key_name: builtins.str
    @property
    def secret_env(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        kms_key_name: builtins.str = ...,
        secret_env: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_name", b"kms_key_name", "secret_env", b"secret_env"]) -> None: ...

global___CloudbuildTriggerXBuildXSecret = CloudbuildTriggerXBuildXSecret

@typing_extensions.final
class CloudbuildTriggerXBuildXSourceXRepoSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SubstitutionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    BRANCH_NAME_FIELD_NUMBER: builtins.int
    COMMIT_SHA_FIELD_NUMBER: builtins.int
    DIR_FIELD_NUMBER: builtins.int
    INVERT_REGEX_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    REPO_NAME_FIELD_NUMBER: builtins.int
    SUBSTITUTIONS_FIELD_NUMBER: builtins.int
    TAG_NAME_FIELD_NUMBER: builtins.int
    branch_name: builtins.str
    commit_sha: builtins.str
    dir: builtins.str
    invert_regex: builtins.bool
    project_id: builtins.str
    repo_name: builtins.str
    @property
    def substitutions(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    tag_name: builtins.str
    def __init__(
        self,
        *,
        branch_name: builtins.str = ...,
        commit_sha: builtins.str = ...,
        dir: builtins.str = ...,
        invert_regex: builtins.bool = ...,
        project_id: builtins.str = ...,
        repo_name: builtins.str = ...,
        substitutions: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tag_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_name", b"branch_name", "commit_sha", b"commit_sha", "dir", b"dir", "invert_regex", b"invert_regex", "project_id", b"project_id", "repo_name", b"repo_name", "substitutions", b"substitutions", "tag_name", b"tag_name"]) -> None: ...

global___CloudbuildTriggerXBuildXSourceXRepoSource = CloudbuildTriggerXBuildXSourceXRepoSource

@typing_extensions.final
class CloudbuildTriggerXBuildXSourceXStorageSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_FIELD_NUMBER: builtins.int
    GENERATION_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    bucket: builtins.str
    generation: builtins.str
    object: builtins.str
    def __init__(
        self,
        *,
        bucket: builtins.str = ...,
        generation: builtins.str = ...,
        object: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "generation", b"generation", "object", b"object"]) -> None: ...

global___CloudbuildTriggerXBuildXSourceXStorageSource = CloudbuildTriggerXBuildXSourceXStorageSource

@typing_extensions.final
class CloudbuildTriggerXBuildXSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPO_SOURCE_FIELD_NUMBER: builtins.int
    STORAGE_SOURCE_FIELD_NUMBER: builtins.int
    @property
    def repo_source(self) -> global___CloudbuildTriggerXBuildXSourceXRepoSource: ...
    @property
    def storage_source(self) -> global___CloudbuildTriggerXBuildXSourceXStorageSource: ...
    def __init__(
        self,
        *,
        repo_source: global___CloudbuildTriggerXBuildXSourceXRepoSource | None = ...,
        storage_source: global___CloudbuildTriggerXBuildXSourceXStorageSource | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["repo_source", b"repo_source", "storage_source", b"storage_source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["repo_source", b"repo_source", "storage_source", b"storage_source"]) -> None: ...

global___CloudbuildTriggerXBuildXSource = CloudbuildTriggerXBuildXSource

@typing_extensions.final
class CloudbuildTriggerXBuildXStepXVolumes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    name: builtins.str
    path: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "path", b"path"]) -> None: ...

global___CloudbuildTriggerXBuildXStepXVolumes = CloudbuildTriggerXBuildXStepXVolumes

@typing_extensions.final
class CloudbuildTriggerXBuildXStep(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARGS_FIELD_NUMBER: builtins.int
    DIR_FIELD_NUMBER: builtins.int
    ENTRYPOINT_FIELD_NUMBER: builtins.int
    ENV_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SECRET_ENV_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    TIMING_FIELD_NUMBER: builtins.int
    WAIT_FOR_FIELD_NUMBER: builtins.int
    VOLUMES_FIELD_NUMBER: builtins.int
    @property
    def args(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    dir: builtins.str
    entrypoint: builtins.str
    @property
    def env(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    id: builtins.str
    name: builtins.str
    @property
    def secret_env(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    timeout: builtins.str
    timing: builtins.str
    @property
    def wait_for(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def volumes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudbuildTriggerXBuildXStepXVolumes]: ...
    def __init__(
        self,
        *,
        args: collections.abc.Iterable[builtins.str] | None = ...,
        dir: builtins.str = ...,
        entrypoint: builtins.str = ...,
        env: collections.abc.Iterable[builtins.str] | None = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        secret_env: collections.abc.Iterable[builtins.str] | None = ...,
        timeout: builtins.str = ...,
        timing: builtins.str = ...,
        wait_for: collections.abc.Iterable[builtins.str] | None = ...,
        volumes: collections.abc.Iterable[global___CloudbuildTriggerXBuildXStepXVolumes] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["args", b"args", "dir", b"dir", "entrypoint", b"entrypoint", "env", b"env", "id", b"id", "name", b"name", "secret_env", b"secret_env", "timeout", b"timeout", "timing", b"timing", "volumes", b"volumes", "wait_for", b"wait_for"]) -> None: ...

global___CloudbuildTriggerXBuildXStep = CloudbuildTriggerXBuildXStep

@typing_extensions.final
class CloudbuildTriggerXBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SubstitutionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IMAGES_FIELD_NUMBER: builtins.int
    LOGS_BUCKET_FIELD_NUMBER: builtins.int
    QUEUE_TTL_FIELD_NUMBER: builtins.int
    SUBSTITUTIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    ARTIFACTS_FIELD_NUMBER: builtins.int
    AVAILABLE_SECRETS_FIELD_NUMBER: builtins.int
    OPTIONS_FIELD_NUMBER: builtins.int
    SECRET_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    STEP_FIELD_NUMBER: builtins.int
    @property
    def images(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    logs_bucket: builtins.str
    queue_ttl: builtins.str
    @property
    def substitutions(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    timeout: builtins.str
    @property
    def artifacts(self) -> global___CloudbuildTriggerXBuildXArtifacts: ...
    @property
    def available_secrets(self) -> global___CloudbuildTriggerXBuildXAvailableSecrets: ...
    @property
    def options(self) -> global___CloudbuildTriggerXBuildXOptions: ...
    @property
    def secret(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudbuildTriggerXBuildXSecret]: ...
    @property
    def source(self) -> global___CloudbuildTriggerXBuildXSource: ...
    @property
    def step(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudbuildTriggerXBuildXStep]: ...
    def __init__(
        self,
        *,
        images: collections.abc.Iterable[builtins.str] | None = ...,
        logs_bucket: builtins.str = ...,
        queue_ttl: builtins.str = ...,
        substitutions: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        timeout: builtins.str = ...,
        artifacts: global___CloudbuildTriggerXBuildXArtifacts | None = ...,
        available_secrets: global___CloudbuildTriggerXBuildXAvailableSecrets | None = ...,
        options: global___CloudbuildTriggerXBuildXOptions | None = ...,
        secret: collections.abc.Iterable[global___CloudbuildTriggerXBuildXSecret] | None = ...,
        source: global___CloudbuildTriggerXBuildXSource | None = ...,
        step: collections.abc.Iterable[global___CloudbuildTriggerXBuildXStep] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["artifacts", b"artifacts", "available_secrets", b"available_secrets", "options", b"options", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["artifacts", b"artifacts", "available_secrets", b"available_secrets", "images", b"images", "logs_bucket", b"logs_bucket", "options", b"options", "queue_ttl", b"queue_ttl", "secret", b"secret", "source", b"source", "step", b"step", "substitutions", b"substitutions", "tags", b"tags", "timeout", b"timeout"]) -> None: ...

global___CloudbuildTriggerXBuild = CloudbuildTriggerXBuild

@typing_extensions.final
class CloudbuildTriggerXGitFileSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    REPO_TYPE_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    path: builtins.str
    repo_type: builtins.str
    revision: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        repo_type: builtins.str = ...,
        revision: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "repo_type", b"repo_type", "revision", b"revision", "uri", b"uri"]) -> None: ...

global___CloudbuildTriggerXGitFileSource = CloudbuildTriggerXGitFileSource

@typing_extensions.final
class CloudbuildTriggerXGithubXPullRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRANCH_FIELD_NUMBER: builtins.int
    COMMENT_CONTROL_FIELD_NUMBER: builtins.int
    INVERT_REGEX_FIELD_NUMBER: builtins.int
    branch: builtins.str
    comment_control: builtins.str
    invert_regex: builtins.bool
    def __init__(
        self,
        *,
        branch: builtins.str = ...,
        comment_control: builtins.str = ...,
        invert_regex: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "comment_control", b"comment_control", "invert_regex", b"invert_regex"]) -> None: ...

global___CloudbuildTriggerXGithubXPullRequest = CloudbuildTriggerXGithubXPullRequest

@typing_extensions.final
class CloudbuildTriggerXGithubXPush(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRANCH_FIELD_NUMBER: builtins.int
    INVERT_REGEX_FIELD_NUMBER: builtins.int
    TAG_FIELD_NUMBER: builtins.int
    branch: builtins.str
    invert_regex: builtins.bool
    tag: builtins.str
    def __init__(
        self,
        *,
        branch: builtins.str = ...,
        invert_regex: builtins.bool = ...,
        tag: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch", b"branch", "invert_regex", b"invert_regex", "tag", b"tag"]) -> None: ...

global___CloudbuildTriggerXGithubXPush = CloudbuildTriggerXGithubXPush

@typing_extensions.final
class CloudbuildTriggerXGithub(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    PULL_REQUEST_FIELD_NUMBER: builtins.int
    PUSH_FIELD_NUMBER: builtins.int
    name: builtins.str
    owner: builtins.str
    @property
    def pull_request(self) -> global___CloudbuildTriggerXGithubXPullRequest: ...
    @property
    def push(self) -> global___CloudbuildTriggerXGithubXPush: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        owner: builtins.str = ...,
        pull_request: global___CloudbuildTriggerXGithubXPullRequest | None = ...,
        push: global___CloudbuildTriggerXGithubXPush | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pull_request", b"pull_request", "push", b"push"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "owner", b"owner", "pull_request", b"pull_request", "push", b"push"]) -> None: ...

global___CloudbuildTriggerXGithub = CloudbuildTriggerXGithub

@typing_extensions.final
class CloudbuildTriggerXPubsubConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_EMAIL_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    service_account_email: builtins.str
    state: builtins.str
    subscription: builtins.str
    topic: builtins.str
    def __init__(
        self,
        *,
        service_account_email: builtins.str = ...,
        state: builtins.str = ...,
        subscription: builtins.str = ...,
        topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_account_email", b"service_account_email", "state", b"state", "subscription", b"subscription", "topic", b"topic"]) -> None: ...

global___CloudbuildTriggerXPubsubConfig = CloudbuildTriggerXPubsubConfig

@typing_extensions.final
class CloudbuildTriggerXSourceToBuild(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REF_FIELD_NUMBER: builtins.int
    REPO_TYPE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    ref: builtins.str
    repo_type: builtins.str
    uri: builtins.str
    def __init__(
        self,
        *,
        ref: builtins.str = ...,
        repo_type: builtins.str = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ref", b"ref", "repo_type", b"repo_type", "uri", b"uri"]) -> None: ...

global___CloudbuildTriggerXSourceToBuild = CloudbuildTriggerXSourceToBuild

@typing_extensions.final
class CloudbuildTriggerXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudbuildTriggerXTimeouts = CloudbuildTriggerXTimeouts

@typing_extensions.final
class CloudbuildTriggerXTriggerTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BRANCH_NAME_FIELD_NUMBER: builtins.int
    COMMIT_SHA_FIELD_NUMBER: builtins.int
    DIR_FIELD_NUMBER: builtins.int
    INVERT_REGEX_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    REPO_NAME_FIELD_NUMBER: builtins.int
    TAG_NAME_FIELD_NUMBER: builtins.int
    branch_name: builtins.str
    commit_sha: builtins.str
    dir: builtins.str
    invert_regex: builtins.bool
    project_id: builtins.str
    repo_name: builtins.str
    tag_name: builtins.str
    def __init__(
        self,
        *,
        branch_name: builtins.str = ...,
        commit_sha: builtins.str = ...,
        dir: builtins.str = ...,
        invert_regex: builtins.bool = ...,
        project_id: builtins.str = ...,
        repo_name: builtins.str = ...,
        tag_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_name", b"branch_name", "commit_sha", b"commit_sha", "dir", b"dir", "invert_regex", b"invert_regex", "project_id", b"project_id", "repo_name", b"repo_name", "tag_name", b"tag_name"]) -> None: ...

global___CloudbuildTriggerXTriggerTemplate = CloudbuildTriggerXTriggerTemplate

@typing_extensions.final
class CloudbuildTriggerXWebhookConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    secret: builtins.str
    state: builtins.str
    def __init__(
        self,
        *,
        secret: builtins.str = ...,
        state: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret", b"secret", "state", b"state"]) -> None: ...

global___CloudbuildTriggerXWebhookConfig = CloudbuildTriggerXWebhookConfig

@typing_extensions.final
class CloudbuildTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class SubstitutionsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    FILENAME_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IGNORED_FILES_FIELD_NUMBER: builtins.int
    INCLUDE_BUILD_LOGS_FIELD_NUMBER: builtins.int
    INCLUDED_FILES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SUBSTITUTIONS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TRIGGER_ID_FIELD_NUMBER: builtins.int
    APPROVAL_CONFIG_FIELD_NUMBER: builtins.int
    BUILD_FIELD_NUMBER: builtins.int
    GIT_FILE_SOURCE_FIELD_NUMBER: builtins.int
    GITHUB_FIELD_NUMBER: builtins.int
    PUBSUB_CONFIG_FIELD_NUMBER: builtins.int
    SOURCE_TO_BUILD_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    TRIGGER_TEMPLATE_FIELD_NUMBER: builtins.int
    WEBHOOK_CONFIG_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    disabled: builtins.bool
    filename: builtins.str
    filter: builtins.str
    id: builtins.str
    @property
    def ignored_files(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    include_build_logs: builtins.str
    @property
    def included_files(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    service_account: builtins.str
    @property
    def substitutions(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    trigger_id: builtins.str
    @property
    def approval_config(self) -> global___CloudbuildTriggerXApprovalConfig: ...
    @property
    def build(self) -> global___CloudbuildTriggerXBuild: ...
    @property
    def git_file_source(self) -> global___CloudbuildTriggerXGitFileSource: ...
    @property
    def github(self) -> global___CloudbuildTriggerXGithub: ...
    @property
    def pubsub_config(self) -> global___CloudbuildTriggerXPubsubConfig: ...
    @property
    def source_to_build(self) -> global___CloudbuildTriggerXSourceToBuild: ...
    @property
    def timeouts(self) -> global___CloudbuildTriggerXTimeouts: ...
    @property
    def trigger_template(self) -> global___CloudbuildTriggerXTriggerTemplate: ...
    @property
    def webhook_config(self) -> global___CloudbuildTriggerXWebhookConfig: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        disabled: builtins.bool = ...,
        filename: builtins.str = ...,
        filter: builtins.str = ...,
        id: builtins.str = ...,
        ignored_files: collections.abc.Iterable[builtins.str] | None = ...,
        include_build_logs: builtins.str = ...,
        included_files: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        service_account: builtins.str = ...,
        substitutions: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        trigger_id: builtins.str = ...,
        approval_config: global___CloudbuildTriggerXApprovalConfig | None = ...,
        build: global___CloudbuildTriggerXBuild | None = ...,
        git_file_source: global___CloudbuildTriggerXGitFileSource | None = ...,
        github: global___CloudbuildTriggerXGithub | None = ...,
        pubsub_config: global___CloudbuildTriggerXPubsubConfig | None = ...,
        source_to_build: global___CloudbuildTriggerXSourceToBuild | None = ...,
        timeouts: global___CloudbuildTriggerXTimeouts | None = ...,
        trigger_template: global___CloudbuildTriggerXTriggerTemplate | None = ...,
        webhook_config: global___CloudbuildTriggerXWebhookConfig | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["approval_config", b"approval_config", "build", b"build", "git_file_source", b"git_file_source", "github", b"github", "pubsub_config", b"pubsub_config", "resource_info", b"resource_info", "source_to_build", b"source_to_build", "timeouts", b"timeouts", "trigger_template", b"trigger_template", "webhook_config", b"webhook_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["approval_config", b"approval_config", "build", b"build", "create_time", b"create_time", "description", b"description", "disabled", b"disabled", "filename", b"filename", "filter", b"filter", "git_file_source", b"git_file_source", "github", b"github", "id", b"id", "ignored_files", b"ignored_files", "include_build_logs", b"include_build_logs", "included_files", b"included_files", "name", b"name", "project", b"project", "pubsub_config", b"pubsub_config", "resource_info", b"resource_info", "service_account", b"service_account", "source_to_build", b"source_to_build", "substitutions", b"substitutions", "tags", b"tags", "timeouts", b"timeouts", "trigger_id", b"trigger_id", "trigger_template", b"trigger_template", "webhook_config", b"webhook_config"]) -> None: ...

global___CloudbuildTrigger = CloudbuildTrigger

@typing_extensions.final
class CloudbuildWorkerPoolXNetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PEERED_NETWORK_FIELD_NUMBER: builtins.int
    peered_network: builtins.str
    def __init__(
        self,
        *,
        peered_network: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["peered_network", b"peered_network"]) -> None: ...

global___CloudbuildWorkerPoolXNetworkConfig = CloudbuildWorkerPoolXNetworkConfig

@typing_extensions.final
class CloudbuildWorkerPoolXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___CloudbuildWorkerPoolXTimeouts = CloudbuildWorkerPoolXTimeouts

@typing_extensions.final
class CloudbuildWorkerPoolXWorkerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    NO_EXTERNAL_IP_FIELD_NUMBER: builtins.int
    disk_size_gb: builtins.float
    machine_type: builtins.str
    no_external_ip: builtins.bool
    def __init__(
        self,
        *,
        disk_size_gb: builtins.float = ...,
        machine_type: builtins.str = ...,
        no_external_ip: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_size_gb", b"disk_size_gb", "machine_type", b"machine_type", "no_external_ip", b"no_external_ip"]) -> None: ...

global___CloudbuildWorkerPoolXWorkerConfig = CloudbuildWorkerPoolXWorkerConfig

@typing_extensions.final
class CloudbuildWorkerPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AnnotationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ANNOTATIONS_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DELETE_TIME_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    NETWORK_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    WORKER_CONFIG_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def annotations(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    create_time: builtins.str
    delete_time: builtins.str
    display_name: builtins.str
    id: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    state: builtins.str
    uid: builtins.str
    update_time: builtins.str
    @property
    def network_config(self) -> global___CloudbuildWorkerPoolXNetworkConfig: ...
    @property
    def timeouts(self) -> global___CloudbuildWorkerPoolXTimeouts: ...
    @property
    def worker_config(self) -> global___CloudbuildWorkerPoolXWorkerConfig: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        annotations: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        create_time: builtins.str = ...,
        delete_time: builtins.str = ...,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        uid: builtins.str = ...,
        update_time: builtins.str = ...,
        network_config: global___CloudbuildWorkerPoolXNetworkConfig | None = ...,
        timeouts: global___CloudbuildWorkerPoolXTimeouts | None = ...,
        worker_config: global___CloudbuildWorkerPoolXWorkerConfig | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_config", b"network_config", "resource_info", b"resource_info", "timeouts", b"timeouts", "worker_config", b"worker_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["annotations", b"annotations", "create_time", b"create_time", "delete_time", b"delete_time", "display_name", b"display_name", "id", b"id", "location", b"location", "name", b"name", "network_config", b"network_config", "project", b"project", "resource_info", b"resource_info", "state", b"state", "timeouts", b"timeouts", "uid", b"uid", "update_time", b"update_time", "worker_config", b"worker_config"]) -> None: ...

global___CloudbuildWorkerPool = CloudbuildWorkerPool



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class DocumentAiProcessorXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___DocumentAiProcessorXTimeouts = DocumentAiProcessorXTimeouts

@typing_extensions.final
class DocumentAiProcessor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    id: builtins.str
    kms_key_name: builtins.str
    location: builtins.str
    name: builtins.str
    project: builtins.str
    type: builtins.str
    @property
    def timeouts(self) -> global___DocumentAiProcessorXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        kms_key_name: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        type: builtins.str = ...,
        timeouts: global___DocumentAiProcessorXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "id", b"id", "kms_key_name", b"kms_key_name", "location", b"location", "name", b"name", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "type", b"type"]) -> None: ...

global___DocumentAiProcessor = DocumentAiProcessor

@typing_extensions.final
class DocumentAiProcessorDefaultVersionXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___DocumentAiProcessorDefaultVersionXTimeouts = DocumentAiProcessorDefaultVersionXTimeouts

@typing_extensions.final
class DocumentAiProcessorDefaultVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROCESSOR_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    processor: builtins.str
    version: builtins.str
    @property
    def timeouts(self) -> global___DocumentAiProcessorDefaultVersionXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        processor: builtins.str = ...,
        version: builtins.str = ...,
        timeouts: global___DocumentAiProcessorDefaultVersionXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "processor", b"processor", "resource_info", b"resource_info", "timeouts", b"timeouts", "version", b"version"]) -> None: ...

global___DocumentAiProcessorDefaultVersion = DocumentAiProcessorDefaultVersion



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_app_containerapps.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-azure/azure_microsoft_app_containerapps.proto\x12-oak9.tython.azure.microsoft_app_containerapps\x1a\x13shared/shared.proto\"\xd4\x02\n\x1bMicrosoft_App_containerApps\x12T\n\x0e\x63ontainer_apps\x18\x01 \x01(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.ContainerApps\x12l\n\x1b\x63ontainer_apps_auth_configs\x18\x02 \x03(\x0b\x32G.oak9.tython.azure.microsoft_app_containerapps.ContainerAppsAuthConfigs\x12q\n\x1d\x63ontainer_apps_sourcecontrols\x18\x03 \x01(\x0b\x32J.oak9.tython.azure.microsoft_app_containerapps.ContainerAppsSourcecontrols\"\xf5\x01\n\x1b\x43ontainerAppsSourcecontrols\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\x12m\n\x1bgithub_action_configuration\x18\x04 \x01(\x0b\x32H.oak9.tython.azure.microsoft_app_containerapps.GithubActionConfiguration\x12\x10\n\x08repo_url\x18\x05 \x01(\t\"\xc2\x02\n\x19GithubActionConfiguration\x12Z\n\x11\x61zure_credentials\x18\x01 \x01(\x0b\x32?.oak9.tython.azure.microsoft_app_containerapps.AzureCredentials\x12\x14\n\x0c\x63ontext_path\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\n\n\x02os\x18\x04 \x01(\t\x12\x14\n\x0cpublish_type\x18\x05 \x01(\t\x12R\n\rregistry_info\x18\x06 \x01(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.RegistryInfo\x12\x15\n\rruntime_stack\x18\x07 \x01(\t\x12\x17\n\x0fruntime_version\x18\x08 \x01(\t\"[\n\x0cRegistryInfo\x12\x19\n\x11registry_password\x18\x01 \x01(\t\x12\x14\n\x0cregistry_url\x18\x02 \x01(\t\x12\x1a\n\x12registry_user_name\x18\x03 \x01(\t\"h\n\x10\x41zureCredentials\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\x15\n\rclient_secret\x18\x02 \x01(\t\x12\x17\n\x0fsubscription_id\x18\x03 \x01(\t\x12\x11\n\ttenant_id\x18\x04 \x01(\t\"\x83\x04\n\x18\x43ontainerAppsAuthConfigs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Z\n\x11global_validation\x18\x03 \x01(\x0b\x32?.oak9.tython.azure.microsoft_app_containerapps.GlobalValidation\x12R\n\rhttp_settings\x18\x04 \x01(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.HttpSettings\x12\\\n\x12identity_providers\x18\x05 \x01(\x0b\x32@.oak9.tython.azure.microsoft_app_containerapps.IdentityProviders\x12\x43\n\x05login\x18\x06 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app_containerapps.Login\x12M\n\x08platform\x18\x07 \x01(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.AuthPlatform\"8\n\x0c\x41uthPlatform\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0fruntime_version\x18\x02 \x01(\t\"\xc7\x02\n\x05Login\x12&\n\x1e\x61llowed_external_redirect_urls\x18\x01 \x03(\t\x12Z\n\x11\x63ookie_expiration\x18\x02 \x01(\x0b\x32?.oak9.tython.azure.microsoft_app_containerapps.CookieExpiration\x12\x43\n\x05nonce\x18\x03 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app_containerapps.Nonce\x12)\n!preserve_url_fragments_for_logins\x18\x04 \x01(\x08\x12J\n\x06routes\x18\x05 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.LoginRoutes\"&\n\x0bLoginRoutes\x12\x17\n\x0flogout_endpoint\x18\x01 \x01(\t\"B\n\x05Nonce\x12!\n\x19nonce_expiration_interval\x18\x01 \x01(\t\x12\x16\n\x0evalidate_nonce\x18\x02 \x01(\x08\"B\n\x10\x43ookieExpiration\x12\x12\n\nconvention\x18\x01 \x01(\t\x12\x1a\n\x12time_to_expiration\x18\x02 \x01(\t\"\x96\x06\n\x11IdentityProviders\x12\x43\n\x05\x61pple\x18\x01 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app_containerapps.Apple\x12\x63\n\x16\x61zure_active_directory\x18\x02 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_app_containerapps.AzureActiveDirectory\x12`\n\x15\x61zure_static_web_apps\x18\x03 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_app_containerapps.AzureStaticWebApps\x12\x8c\x01\n custom_open_id_connect_providers\x18\x04 \x03(\x0b\x32\x62.oak9.tython.azure.microsoft_app_containerapps.IdentityProviders.CustomOpenIdConnectProvidersEntry\x12I\n\x08\x66\x61\x63\x65\x62ook\x18\x05 \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_app_containerapps.Facebook\x12\x46\n\x07git_hub\x18\x06 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_app_containerapps.GitHub\x12\x45\n\x06google\x18\x07 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_app_containerapps.Google\x12G\n\x07twitter\x18\x08 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_app_containerapps.Twitter\x1a\x43\n!CustomOpenIdConnectProvidersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\x07Twitter\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12X\n\x0cregistration\x18\x02 \x01(\x0b\x32\x42.oak9.tython.azure.microsoft_app_containerapps.TwitterRegistration\"Q\n\x13TwitterRegistration\x12\x14\n\x0c\x63onsumer_key\x18\x01 \x01(\t\x12$\n\x1c\x63onsumer_secret_setting_name\x18\x02 \x01(\t\"\x9c\x02\n\x06Google\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12I\n\x05login\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.LoginScopes\x12W\n\x0cregistration\x18\x03 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_app_containerapps.ClientRegistration\x12]\n\nvalidation\x18\x04 \x01(\x0b\x32I.oak9.tython.azure.microsoft_app_containerapps.AllowedAudiencesValidation\"7\n\x1a\x41llowedAudiencesValidation\x12\x19\n\x11\x61llowed_audiences\x18\x01 \x03(\t\"\xbd\x01\n\x06GitHub\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12I\n\x05login\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.LoginScopes\x12W\n\x0cregistration\x18\x03 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_app_containerapps.ClientRegistration\"K\n\x12\x43lientRegistration\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\"\n\x1a\x63lient_secret_setting_name\x18\x02 \x01(\t\"\xd7\x01\n\x08\x46\x61\x63\x65\x62ook\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x19\n\x11graph_api_version\x18\x02 \x01(\t\x12I\n\x05login\x18\x03 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.LoginScopes\x12T\n\x0cregistration\x18\x04 \x01(\x0b\x32>.oak9.tython.azure.microsoft_app_containerapps.AppRegistration\"B\n\x0f\x41ppRegistration\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x1f\n\x17\x61pp_secret_setting_name\x18\x02 \x01(\t\"\x8a\x01\n\x12\x41zureStaticWebApps\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x63\n\x0cregistration\x18\x02 \x01(\x0b\x32M.oak9.tython.azure.microsoft_app_containerapps.AzureStaticWebAppsRegistration\"3\n\x1e\x41zureStaticWebAppsRegistration\x12\x11\n\tclient_id\x18\x01 \x01(\t\"\xe7\x02\n\x14\x41zureActiveDirectory\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x1b\n\x13is_auto_provisioned\x18\x02 \x01(\x08\x12W\n\x05login\x18\x03 \x01(\x0b\x32H.oak9.tython.azure.microsoft_app_containerapps.AzureActiveDirectoryLogin\x12\x65\n\x0cregistration\x18\x04 \x01(\x0b\x32O.oak9.tython.azure.microsoft_app_containerapps.AzureActiveDirectoryRegistration\x12\x61\n\nvalidation\x18\x05 \x01(\x0b\x32M.oak9.tython.azure.microsoft_app_containerapps.AzureActiveDirectoryValidation\"\x85\x02\n\x1e\x41zureActiveDirectoryValidation\x12\x19\n\x11\x61llowed_audiences\x18\x01 \x03(\t\x12o\n\x1c\x64\x65\x66\x61ult_authorization_policy\x18\x02 \x01(\x0b\x32I.oak9.tython.azure.microsoft_app_containerapps.DefaultAuthorizationPolicy\x12W\n\x10jwt_claim_checks\x18\x03 \x01(\x0b\x32=.oak9.tython.azure.microsoft_app_containerapps.JwtClaimChecks\"M\n\x0eJwtClaimChecks\x12#\n\x1b\x61llowed_client_applications\x18\x01 \x03(\t\x12\x16\n\x0e\x61llowed_groups\x18\x02 \x03(\t\"\x98\x01\n\x1a\x44\x65\x66\x61ultAuthorizationPolicy\x12\x1c\n\x14\x61llowed_applications\x18\x01 \x03(\t\x12\\\n\x12\x61llowed_principals\x18\x02 \x01(\x0b\x32@.oak9.tython.azure.microsoft_app_containerapps.AllowedPrincipals\"7\n\x11\x41llowedPrincipals\x12\x0e\n\x06groups\x18\x01 \x03(\t\x12\x12\n\nidentities\x18\x02 \x03(\t\"\x85\x02\n AzureActiveDirectoryRegistration\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12(\n client_secret_certificate_issuer\x18\x02 \x01(\t\x12:\n2client_secret_certificate_subject_alternative_name\x18\x03 \x01(\t\x12,\n$client_secret_certificate_thumbprint\x18\x04 \x01(\t\x12\"\n\x1a\x63lient_secret_setting_name\x18\x05 \x01(\t\x12\x16\n\x0eopen_id_issuer\x18\x06 \x01(\t\"Y\n\x19\x41zureActiveDirectoryLogin\x12\"\n\x1a\x64isable_w_w_w_authenticate\x18\x01 \x01(\x08\x12\x18\n\x10login_parameters\x18\x02 \x03(\t\"\xbb\x01\n\x05\x41pple\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12I\n\x05login\x18\x02 \x01(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.LoginScopes\x12V\n\x0cregistration\x18\x03 \x01(\x0b\x32@.oak9.tython.azure.microsoft_app_containerapps.AppleRegistration\"J\n\x11\x41ppleRegistration\x12\x11\n\tclient_id\x18\x01 \x01(\t\x12\"\n\x1a\x63lient_secret_setting_name\x18\x02 \x01(\t\"\x1d\n\x0bLoginScopes\x12\x0e\n\x06scopes\x18\x01 \x03(\t\"\xcc\x01\n\x0cHttpSettings\x12R\n\rforward_proxy\x18\x01 \x01(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.ForwardProxy\x12\x15\n\rrequire_https\x18\x02 \x01(\x08\x12Q\n\x06routes\x18\x03 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_app_containerapps.HttpSettingsRoutes\"(\n\x12HttpSettingsRoutes\x12\x12\n\napi_prefix\x18\x01 \x01(\t\"e\n\x0c\x46orwardProxy\x12\x12\n\nconvention\x18\x01 \x01(\t\x12\x1f\n\x17\x63ustom_host_header_name\x18\x02 \x01(\t\x12 \n\x18\x63ustom_proto_header_name\x18\x03 \x01(\t\"o\n\x10GlobalValidation\x12\x16\n\x0e\x65xcluded_paths\x18\x01 \x03(\t\x12\x1c\n\x14redirect_to_provider\x18\x02 \x01(\t\x12%\n\x1dunauthenticated_client_action\x18\x03 \x01(\t\"\x97\x05\n\rContainerApps\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Z\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32?.oak9.tython.azure.microsoft_app_containerapps.ExtendedLocation\x12W\n\x08identity\x18\x03 \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_app_containerapps.ManagedServiceIdentity\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12S\n\rconfiguration\x18\x06 \x01(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.Configuration\x12\x16\n\x0e\x65nvironment_id\x18\x07 \x01(\t\x12\x1e\n\x16managed_environment_id\x18\x08 \x01(\t\x12I\n\x08template\x18\t \x01(\x0b\x32\x37.oak9.tython.azure.microsoft_app_containerapps.Template\x12\x1d\n\x15workload_profile_type\x18\n \x01(\t\x12T\n\x04tags\x18\x0b \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_app_containerapps.ContainerApps.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd5\x02\n\x08Template\x12L\n\ncontainers\x18\x01 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_app_containerapps.Container\x12U\n\x0finit_containers\x18\x02 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.InitContainer\x12\x17\n\x0frevision_suffix\x18\x03 \x01(\t\x12\x43\n\x05scale\x18\x04 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_app_containerapps.Scale\x12\x46\n\x07volumes\x18\x05 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_app_containerapps.Volume\"B\n\x06Volume\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cstorage_name\x18\x02 \x01(\t\x12\x14\n\x0cstorage_type\x18\x03 \x01(\t\"|\n\x05Scale\x12\x14\n\x0cmax_replicas\x18\x01 \x01(\x05\x12\x14\n\x0cmin_replicas\x18\x02 \x01(\x05\x12G\n\x05rules\x18\x03 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_app_containerapps.ScaleRule\"\xd3\x02\n\tScaleRule\x12R\n\x0b\x61zure_queue\x18\x01 \x01(\x0b\x32=.oak9.tython.azure.microsoft_app_containerapps.QueueScaleRule\x12N\n\x06\x63ustom\x18\x02 \x01(\x0b\x32>.oak9.tython.azure.microsoft_app_containerapps.CustomScaleRule\x12J\n\x04http\x18\x03 \x01(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.HttpScaleRule\x12\x0c\n\x04name\x18\x04 \x01(\t\x12H\n\x03tcp\x18\x05 \x01(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.TcpScaleRule\"\xe8\x01\n\x0cTcpScaleRule\x12J\n\x04\x61uth\x18\x01 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.ScaleRuleAuth\x12[\n\x08metadata\x18\x02 \x03(\x0b\x32I.oak9.tython.azure.microsoft_app_containerapps.TcpScaleRule.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xea\x01\n\rHttpScaleRule\x12J\n\x04\x61uth\x18\x01 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.ScaleRuleAuth\x12\\\n\x08metadata\x18\x02 \x03(\x0b\x32J.oak9.tython.azure.microsoft_app_containerapps.HttpScaleRule.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfc\x01\n\x0f\x43ustomScaleRule\x12J\n\x04\x61uth\x18\x01 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.ScaleRuleAuth\x12^\n\x08metadata\x18\x02 \x03(\x0b\x32L.oak9.tython.azure.microsoft_app_containerapps.CustomScaleRule.MetadataEntry\x12\x0c\n\x04type\x18\x03 \x01(\t\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x0eQueueScaleRule\x12J\n\x04\x61uth\x18\x01 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.ScaleRuleAuth\x12\x14\n\x0cqueue_length\x18\x02 \x01(\x05\x12\x12\n\nqueue_name\x18\x03 \x01(\t\">\n\rScaleRuleAuth\x12\x12\n\nsecret_ref\x18\x01 \x01(\t\x12\x19\n\x11trigger_parameter\x18\x02 \x01(\t\"\xea\x01\n\rInitContainer\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12J\n\x03\x65nv\x18\x03 \x03(\x0b\x32=.oak9.tython.azure.microsoft_app_containerapps.EnvironmentVar\x12\r\n\x05image\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12Q\n\rvolume_mounts\x18\x06 \x03(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.VolumeMount\"\xb8\x02\n\tContainer\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12J\n\x03\x65nv\x18\x03 \x03(\x0b\x32=.oak9.tython.azure.microsoft_app_containerapps.EnvironmentVar\x12\r\n\x05image\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12P\n\x06probes\x18\x06 \x03(\x0b\x32@.oak9.tython.azure.microsoft_app_containerapps.ContainerAppProbe\x12Q\n\rvolume_mounts\x18\x07 \x03(\x0b\x32:.oak9.tython.azure.microsoft_app_containerapps.VolumeMount\"6\n\x0bVolumeMount\x12\x12\n\nmount_path\x18\x01 \x01(\t\x12\x13\n\x0bvolume_name\x18\x02 \x01(\t\"\x8b\x03\n\x11\x43ontainerAppProbe\x12\x19\n\x11\x66\x61ilure_threshold\x18\x01 \x01(\x05\x12Y\n\x08http_get\x18\x02 \x01(\x0b\x32G.oak9.tython.azure.microsoft_app_containerapps.ContainerAppProbeHttpGet\x12\x1d\n\x15initial_delay_seconds\x18\x03 \x01(\x05\x12\x16\n\x0eperiod_seconds\x18\x04 \x01(\x05\x12\x19\n\x11success_threshold\x18\x05 \x01(\x05\x12]\n\ntcp_socket\x18\x06 \x01(\x0b\x32I.oak9.tython.azure.microsoft_app_containerapps.ContainerAppProbeTcpSocket\x12(\n termination_grace_period_seconds\x18\x07 \x01(\x05\x12\x17\n\x0ftimeout_seconds\x18\x08 \x01(\x05\x12\x0c\n\x04type\x18\t \x01(\t\"8\n\x1a\x43ontainerAppProbeTcpSocket\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\"\xc2\x01\n\x18\x43ontainerAppProbeHttpGet\x12\x0c\n\x04host\x18\x01 \x01(\t\x12l\n\x0chttp_headers\x18\x02 \x03(\x0b\x32V.oak9.tython.azure.microsoft_app_containerapps.ContainerAppProbeHttpGetHttpHeadersItem\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x0e\n\x06scheme\x18\x05 \x01(\t\"F\n\'ContainerAppProbeHttpGetHttpHeadersItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"A\n\x0e\x45nvironmentVar\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nsecret_ref\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xfa\x02\n\rConfiguration\x12\x1d\n\x15\x61\x63tive_revisions_mode\x18\x01 \x01(\t\x12\x41\n\x04\x64\x61pr\x18\x02 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_app_containerapps.Dapr\x12G\n\x07ingress\x18\x03 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_app_containerapps.Ingress\x12\x1e\n\x16max_inactive_revisions\x18\x04 \x01(\x05\x12V\n\nregistries\x18\x05 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_app_containerapps.RegistryCredentials\x12\x46\n\x07secrets\x18\x06 \x03(\x0b\x32\x35.oak9.tython.azure.microsoft_app_containerapps.Secret\"%\n\x06Secret\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"f\n\x13RegistryCredentials\x12\x10\n\x08identity\x18\x01 \x01(\t\x12\x1b\n\x13password_secret_ref\x18\x02 \x01(\t\x12\x0e\n\x06server\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\"\x81\x03\n\x07Ingress\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12S\n\x0e\x63ustom_domains\x18\x02 \x03(\x0b\x32;.oak9.tython.azure.microsoft_app_containerapps.CustomDomain\x12\x14\n\x0c\x65xposed_port\x18\x03 \x01(\x05\x12\x10\n\x08\x65xternal\x18\x04 \x01(\x08\x12j\n\x18ip_security_restrictions\x18\x05 \x03(\x0b\x32H.oak9.tython.azure.microsoft_app_containerapps.IpSecurityRestrictionRule\x12\x13\n\x0btarget_port\x18\x06 \x01(\x05\x12M\n\x07traffic\x18\x07 \x03(\x0b\x32<.oak9.tython.azure.microsoft_app_containerapps.TrafficWeight\x12\x11\n\ttransport\x18\x08 \x01(\t\"^\n\rTrafficWeight\x12\r\n\x05label\x18\x01 \x01(\t\x12\x17\n\x0flatest_revision\x18\x02 \x01(\x08\x12\x15\n\rrevision_name\x18\x03 \x01(\t\x12\x0e\n\x06weight\x18\x04 \x01(\x05\"h\n\x19IpSecurityRestrictionRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10ip_address_range\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"J\n\x0c\x43ustomDomain\x12\x14\n\x0c\x62inding_type\x18\x01 \x01(\t\x12\x16\n\x0e\x63\x65rtificate_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xbc\x01\n\x04\x44\x61pr\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x10\n\x08\x61pp_port\x18\x02 \x01(\x05\x12\x14\n\x0c\x61pp_protocol\x18\x03 \x01(\t\x12\x1a\n\x12\x65nable_api_logging\x18\x04 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x1d\n\x15http_max_request_size\x18\x06 \x01(\x05\x12\x1d\n\x15http_read_buffer_size\x18\x07 \x01(\x05\x12\x11\n\tlog_level\x18\x08 \x01(\t\"\xeb\x01\n\x16ManagedServiceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x83\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32\x61.oak9.tython.azure.microsoft_app_containerapps.ManagedServiceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_app_containerapps_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _IDENTITYPROVIDERS_CUSTOMOPENIDCONNECTPROVIDERSENTRY._options = None
  _IDENTITYPROVIDERS_CUSTOMOPENIDCONNECTPROVIDERSENTRY._serialized_options = b'8\001'
  _CONTAINERAPPS_TAGSENTRY._options = None
  _CONTAINERAPPS_TAGSENTRY._serialized_options = b'8\001'
  _TCPSCALERULE_METADATAENTRY._options = None
  _TCPSCALERULE_METADATAENTRY._serialized_options = b'8\001'
  _HTTPSCALERULE_METADATAENTRY._options = None
  _HTTPSCALERULE_METADATAENTRY._serialized_options = b'8\001'
  _CUSTOMSCALERULE_METADATAENTRY._options = None
  _CUSTOMSCALERULE_METADATAENTRY._serialized_options = b'8\001'
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_APP_CONTAINERAPPS._serialized_start=118
  _MICROSOFT_APP_CONTAINERAPPS._serialized_end=458
  _CONTAINERAPPSSOURCECONTROLS._serialized_start=461
  _CONTAINERAPPSSOURCECONTROLS._serialized_end=706
  _GITHUBACTIONCONFIGURATION._serialized_start=709
  _GITHUBACTIONCONFIGURATION._serialized_end=1031
  _REGISTRYINFO._serialized_start=1033
  _REGISTRYINFO._serialized_end=1124
  _AZURECREDENTIALS._serialized_start=1126
  _AZURECREDENTIALS._serialized_end=1230
  _CONTAINERAPPSAUTHCONFIGS._serialized_start=1233
  _CONTAINERAPPSAUTHCONFIGS._serialized_end=1748
  _AUTHPLATFORM._serialized_start=1750
  _AUTHPLATFORM._serialized_end=1806
  _LOGIN._serialized_start=1809
  _LOGIN._serialized_end=2136
  _LOGINROUTES._serialized_start=2138
  _LOGINROUTES._serialized_end=2176
  _NONCE._serialized_start=2178
  _NONCE._serialized_end=2244
  _COOKIEEXPIRATION._serialized_start=2246
  _COOKIEEXPIRATION._serialized_end=2312
  _IDENTITYPROVIDERS._serialized_start=2315
  _IDENTITYPROVIDERS._serialized_end=3105
  _IDENTITYPROVIDERS_CUSTOMOPENIDCONNECTPROVIDERSENTRY._serialized_start=3038
  _IDENTITYPROVIDERS_CUSTOMOPENIDCONNECTPROVIDERSENTRY._serialized_end=3105
  _TWITTER._serialized_start=3107
  _TWITTER._serialized_end=3223
  _TWITTERREGISTRATION._serialized_start=3225
  _TWITTERREGISTRATION._serialized_end=3306
  _GOOGLE._serialized_start=3309
  _GOOGLE._serialized_end=3593
  _ALLOWEDAUDIENCESVALIDATION._serialized_start=3595
  _ALLOWEDAUDIENCESVALIDATION._serialized_end=3650
  _GITHUB._serialized_start=3653
  _GITHUB._serialized_end=3842
  _CLIENTREGISTRATION._serialized_start=3844
  _CLIENTREGISTRATION._serialized_end=3919
  _FACEBOOK._serialized_start=3922
  _FACEBOOK._serialized_end=4137
  _APPREGISTRATION._serialized_start=4139
  _APPREGISTRATION._serialized_end=4205
  _AZURESTATICWEBAPPS._serialized_start=4208
  _AZURESTATICWEBAPPS._serialized_end=4346
  _AZURESTATICWEBAPPSREGISTRATION._serialized_start=4348
  _AZURESTATICWEBAPPSREGISTRATION._serialized_end=4399
  _AZUREACTIVEDIRECTORY._serialized_start=4402
  _AZUREACTIVEDIRECTORY._serialized_end=4761
  _AZUREACTIVEDIRECTORYVALIDATION._serialized_start=4764
  _AZUREACTIVEDIRECTORYVALIDATION._serialized_end=5025
  _JWTCLAIMCHECKS._serialized_start=5027
  _JWTCLAIMCHECKS._serialized_end=5104
  _DEFAULTAUTHORIZATIONPOLICY._serialized_start=5107
  _DEFAULTAUTHORIZATIONPOLICY._serialized_end=5259
  _ALLOWEDPRINCIPALS._serialized_start=5261
  _ALLOWEDPRINCIPALS._serialized_end=5316
  _AZUREACTIVEDIRECTORYREGISTRATION._serialized_start=5319
  _AZUREACTIVEDIRECTORYREGISTRATION._serialized_end=5580
  _AZUREACTIVEDIRECTORYLOGIN._serialized_start=5582
  _AZUREACTIVEDIRECTORYLOGIN._serialized_end=5671
  _APPLE._serialized_start=5674
  _APPLE._serialized_end=5861
  _APPLEREGISTRATION._serialized_start=5863
  _APPLEREGISTRATION._serialized_end=5937
  _LOGINSCOPES._serialized_start=5939
  _LOGINSCOPES._serialized_end=5968
  _HTTPSETTINGS._serialized_start=5971
  _HTTPSETTINGS._serialized_end=6175
  _HTTPSETTINGSROUTES._serialized_start=6177
  _HTTPSETTINGSROUTES._serialized_end=6217
  _FORWARDPROXY._serialized_start=6219
  _FORWARDPROXY._serialized_end=6320
  _GLOBALVALIDATION._serialized_start=6322
  _GLOBALVALIDATION._serialized_end=6433
  _CONTAINERAPPS._serialized_start=6436
  _CONTAINERAPPS._serialized_end=7099
  _CONTAINERAPPS_TAGSENTRY._serialized_start=7056
  _CONTAINERAPPS_TAGSENTRY._serialized_end=7099
  _TEMPLATE._serialized_start=7102
  _TEMPLATE._serialized_end=7443
  _VOLUME._serialized_start=7445
  _VOLUME._serialized_end=7511
  _SCALE._serialized_start=7513
  _SCALE._serialized_end=7637
  _SCALERULE._serialized_start=7640
  _SCALERULE._serialized_end=7979
  _TCPSCALERULE._serialized_start=7982
  _TCPSCALERULE._serialized_end=8214
  _TCPSCALERULE_METADATAENTRY._serialized_start=8167
  _TCPSCALERULE_METADATAENTRY._serialized_end=8214
  _HTTPSCALERULE._serialized_start=8217
  _HTTPSCALERULE._serialized_end=8451
  _HTTPSCALERULE_METADATAENTRY._serialized_start=8167
  _HTTPSCALERULE_METADATAENTRY._serialized_end=8214
  _CUSTOMSCALERULE._serialized_start=8454
  _CUSTOMSCALERULE._serialized_end=8706
  _CUSTOMSCALERULE_METADATAENTRY._serialized_start=8167
  _CUSTOMSCALERULE_METADATAENTRY._serialized_end=8214
  _QUEUESCALERULE._serialized_start=8709
  _QUEUESCALERULE._serialized_end=8843
  _SCALERULEAUTH._serialized_start=8845
  _SCALERULEAUTH._serialized_end=8907
  _INITCONTAINER._serialized_start=8910
  _INITCONTAINER._serialized_end=9144
  _CONTAINER._serialized_start=9147
  _CONTAINER._serialized_end=9459
  _VOLUMEMOUNT._serialized_start=9461
  _VOLUMEMOUNT._serialized_end=9515
  _CONTAINERAPPPROBE._serialized_start=9518
  _CONTAINERAPPPROBE._serialized_end=9913
  _CONTAINERAPPPROBETCPSOCKET._serialized_start=9915
  _CONTAINERAPPPROBETCPSOCKET._serialized_end=9971
  _CONTAINERAPPPROBEHTTPGET._serialized_start=9974
  _CONTAINERAPPPROBEHTTPGET._serialized_end=10168
  _CONTAINERAPPPROBEHTTPGETHTTPHEADERSITEM._serialized_start=10170
  _CONTAINERAPPPROBEHTTPGETHTTPHEADERSITEM._serialized_end=10240
  _ENVIRONMENTVAR._serialized_start=10242
  _ENVIRONMENTVAR._serialized_end=10307
  _CONFIGURATION._serialized_start=10310
  _CONFIGURATION._serialized_end=10688
  _SECRET._serialized_start=10690
  _SECRET._serialized_end=10727
  _REGISTRYCREDENTIALS._serialized_start=10729
  _REGISTRYCREDENTIALS._serialized_end=10831
  _INGRESS._serialized_start=10834
  _INGRESS._serialized_end=11219
  _TRAFFICWEIGHT._serialized_start=11221
  _TRAFFICWEIGHT._serialized_end=11315
  _IPSECURITYRESTRICTIONRULE._serialized_start=11317
  _IPSECURITYRESTRICTIONRULE._serialized_end=11421
  _CUSTOMDOMAIN._serialized_start=11423
  _CUSTOMDOMAIN._serialized_end=11497
  _DAPR._serialized_start=11500
  _DAPR._serialized_end=11688
  _MANAGEDSERVICEIDENTITY._serialized_start=11691
  _MANAGEDSERVICEIDENTITY._serialized_end=11926
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=11865
  _MANAGEDSERVICEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=11926
  _EXTENDEDLOCATION._serialized_start=11928
  _EXTENDEDLOCATION._serialized_end=11974
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RepositoryRepositoryTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    BRANCHES_FIELD_NUMBER: builtins.int
    CUSTOM_DATA_FIELD_NUMBER: builtins.int
    DESTINATION_ARN_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def branches(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    custom_data: builtins.str
    destination_arn: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        events: collections.abc.Iterable[builtins.str] | None = ...,
        branches: collections.abc.Iterable[builtins.str] | None = ...,
        custom_data: builtins.str = ...,
        destination_arn: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branches", b"branches", "custom_data", b"custom_data", "destination_arn", b"destination_arn", "events", b"events", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___RepositoryRepositoryTrigger = RepositoryRepositoryTrigger

@typing_extensions.final
class RepositoryS3(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    OBJECT_VERSION_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    object_version: builtins.str
    bucket: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        object_version: builtins.str = ...,
        bucket: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "key", b"key", "object_version", b"object_version", "resource_info", b"resource_info"]) -> None: ...

global___RepositoryS3 = RepositoryS3

@typing_extensions.final
class RepositoryCode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_FIELD_NUMBER: builtins.int
    BRANCH_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def s3(self) -> global___RepositoryS3: ...
    branch_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3: global___RepositoryS3 | None = ...,
        branch_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3", b"s3"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["branch_name", b"branch_name", "resource_info", b"resource_info", "s3", b"s3"]) -> None: ...

global___RepositoryCode = RepositoryCode

@typing_extensions.final
class Repository(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REPOSITORY_NAME_FIELD_NUMBER: builtins.int
    TRIGGERS_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    REPOSITORY_DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    repository_name: builtins.str
    @property
    def triggers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RepositoryRepositoryTrigger]: ...
    @property
    def code(self) -> global___RepositoryCode: ...
    repository_description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        repository_name: builtins.str = ...,
        triggers: collections.abc.Iterable[global___RepositoryRepositoryTrigger] | None = ...,
        code: global___RepositoryCode | None = ...,
        repository_description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["code", b"code", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "repository_description", b"repository_description", "repository_name", b"repository_name", "resource_info", b"resource_info", "tags", b"tags", "triggers", b"triggers"]) -> None: ...

global___Repository = Repository

@typing_extensions.final
class CodeCommit(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPOSITORY_FIELD_NUMBER: builtins.int
    @property
    def repository(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Repository]: ...
    def __init__(
        self,
        *,
        repository: collections.abc.Iterable[global___Repository] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["repository", b"repository"]) -> None: ...

global___CodeCommit = CodeCommit



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_autoscaler.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n gcp/gcp_compute_autoscaler.proto\x12\"oak9.tython.gcp.compute_autoscaler\x1a\x13shared/shared.proto\"_\n2ComputeAutoscalerXAutoscalingPolicyXCpuUtilization\x12\x19\n\x11predictive_method\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\x01\"N\n<ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization\x12\x0e\n\x06target\x18\x01 \x01(\x01\"X\n*ComputeAutoscalerXAutoscalingPolicyXMetric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\x01\x12\x0c\n\x04type\x18\x03 \x01(\t\"h\nFComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas\x12\r\n\x05\x66ixed\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xda\x01\n2ComputeAutoscalerXAutoscalingPolicyXScaleInControl\x12\x17\n\x0ftime_window_sec\x18\x01 \x01(\x01\x12\x8a\x01\n\x16max_scaled_in_replicas\x18\x02 \x01(\x0b\x32j.oak9.tython.gcp.compute_autoscaler.ComputeAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas\"\xc5\x01\n4ComputeAutoscalerXAutoscalingPolicyXScalingSchedules\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x14\n\x0c\x64uration_sec\x18\x03 \x01(\x01\x12\x1d\n\x15min_required_replicas\x18\x04 \x01(\x01\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08schedule\x18\x06 \x01(\t\x12\x11\n\ttime_zone\x18\x07 \x01(\t\"\xb7\x05\n#ComputeAutoscalerXAutoscalingPolicy\x12\x17\n\x0f\x63ooldown_period\x18\x01 \x01(\x01\x12\x14\n\x0cmax_replicas\x18\x02 \x01(\x01\x12\x14\n\x0cmin_replicas\x18\x03 \x01(\x01\x12\x0c\n\x04mode\x18\x04 \x01(\t\x12o\n\x0f\x63pu_utilization\x18\x05 \x01(\x0b\x32V.oak9.tython.gcp.compute_autoscaler.ComputeAutoscalerXAutoscalingPolicyXCpuUtilization\x12\x84\x01\n\x1aload_balancing_utilization\x18\x06 \x01(\x0b\x32`.oak9.tython.gcp.compute_autoscaler.ComputeAutoscalerXAutoscalingPolicyXLoadBalancingUtilization\x12^\n\x06metric\x18\x07 \x03(\x0b\x32N.oak9.tython.gcp.compute_autoscaler.ComputeAutoscalerXAutoscalingPolicyXMetric\x12p\n\x10scale_in_control\x18\x08 \x01(\x0b\x32V.oak9.tython.gcp.compute_autoscaler.ComputeAutoscalerXAutoscalingPolicyXScaleInControl\x12s\n\x11scaling_schedules\x18\t \x03(\x0b\x32X.oak9.tython.gcp.compute_autoscaler.ComputeAutoscalerXAutoscalingPolicyXScalingSchedules\"L\n\x1a\x43omputeAutoscalerXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x90\x03\n\x11\x43omputeAutoscaler\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x11\n\tself_link\x18\x06 \x01(\t\x12\x0e\n\x06target\x18\x07 \x01(\t\x12\x0c\n\x04zone\x18\x08 \x01(\t\x12\x63\n\x12\x61utoscaling_policy\x18\t \x01(\x0b\x32G.oak9.tython.gcp.compute_autoscaler.ComputeAutoscalerXAutoscalingPolicy\x12P\n\x08timeouts\x18\n \x01(\x0b\x32>.oak9.tython.gcp.compute_autoscaler.ComputeAutoscalerXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_autoscaler_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXCPUUTILIZATION._serialized_start=93
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXCPUUTILIZATION._serialized_end=188
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXLOADBALANCINGUTILIZATION._serialized_start=190
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXLOADBALANCINGUTILIZATION._serialized_end=268
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXMETRIC._serialized_start=270
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXMETRIC._serialized_end=358
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXSCALEINCONTROLXMAXSCALEDINREPLICAS._serialized_start=360
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXSCALEINCONTROLXMAXSCALEDINREPLICAS._serialized_end=464
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXSCALEINCONTROL._serialized_start=467
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXSCALEINCONTROL._serialized_end=685
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXSCALINGSCHEDULES._serialized_start=688
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICYXSCALINGSCHEDULES._serialized_end=885
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICY._serialized_start=888
  _COMPUTEAUTOSCALERXAUTOSCALINGPOLICY._serialized_end=1583
  _COMPUTEAUTOSCALERXTIMEOUTS._serialized_start=1585
  _COMPUTEAUTOSCALERXTIMEOUTS._serialized_end=1661
  _COMPUTEAUTOSCALER._serialized_start=1664
  _COMPUTEAUTOSCALER._serialized_end=2064
# @@protoc_insertion_point(module_scope)
